@@ -11,14 +11,14 @@
 
 using namespace Editor;
 
-BrowserWidget::BrowserWidget(QWidget *parent) : QWidget(parent)
+BrowserWidget::BrowserWidget(QWidget *parent)
+    : QWidget(parent)
+    , m_htmlPart{new QWebEngineView(widget)}
 {
     setupUi(this);
     m_currentTranslation = -1;
-    m_entry = 0;
     m_currentProvider = 0; ///@todo kconfig?
 
-    m_htmlPart = new QWebEngineView(widget);
     QHBoxLayout *layout = new QHBoxLayout(widget);
     widget->setLayout(layout);
     layout->addWidget(m_htmlPart);
@@ -27,7 +27,6 @@ BrowserWidget::BrowserWidget(QWidget *parent) : QWidget(parent)
 
     setupProviders();
     connect(providerComboBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &BrowserWidget::providerChanged);
-
 }
 
 void BrowserWidget::setupProviders()
@@ -84,14 +83,16 @@ void BrowserWidget::setupProviders()
     providerComboBox->addItem(provider.name);
 
     provider.name = QStringLiteral("Heinzelnisse");
-    provider.url = QStringLiteral("https://heinzelnisse.info/dict?setOptions=true&searchItem=\\{@}&dictDeNoSearch=on&dictNoDeSearch=on&dictExactSearch=on&dictPhoneticSearch=on&wikiSearch=on&dictNynorskSearch=on&dictBokmaalSearch=checked&forumKeywordSearch=on&suggestion=on");
+    provider.url = QStringLiteral(
+        "https://heinzelnisse.info/"
+        "dict?setOptions=true&searchItem=\\{@}&dictDeNoSearch=on&dictNoDeSearch=on&dictExactSearch=on&dictPhoneticSearch=on&wikiSearch=on&dictNynorskSearch=on&"
+        "dictBokmaalSearch=checked&forumKeywordSearch=on&suggestion=on");
     provider.languages << QStringLiteral("no") << QStringLiteral("de");
     m_providers.append(provider);
     providerComboBox->addItem(provider.name);
-
 }
 
-void BrowserWidget::setTranslation(KEduVocExpression* entry, int translation)
+void BrowserWidget::setTranslation(KEduVocExpression *entry, int translation)
 {
     m_currentTranslation = translation;
     m_entry = entry;
@@ -114,7 +115,7 @@ void BrowserWidget::showCurrentTranslation()
     }
 }
 
-void BrowserWidget::openUrl(const QUrl & targetUrl)
+void BrowserWidget::openUrl(const QUrl &targetUrl)
 {
     m_htmlPart->load(targetUrl);
     m_htmlPart->show();
