@@ -30,10 +30,10 @@ public:
 
 signals:
     /** A lesson was selected */
-    void selectedLessonChanged(KEduVocLesson* lesson);
+    void selectedLessonChanged(KEduVocLesson *lesson);
 
     /** Emitted when a new container is selected. Indicates the selected container. */
-    void signalShowContainer(KEduVocContainer* selected);
+    void signalShowContainer(KEduVocContainer *selected);
 
     /** Emitted when any of the checkboxes for the query change. */
     void lessonsInPracticeChanged();
@@ -50,6 +50,11 @@ public slots:
      */
     void slotSplitLesson();
 
+    /**
+     * Moves the selected vocabs to a new lession
+     */
+    void moveToNewLesson();
+
     /** Remove the grades for the selected lesson.  */
     void slotRemoveGradesLesson();
 
@@ -61,7 +66,7 @@ public slots:
      */
     void columnsInserted();
 
-    void setTranslation(KEduVocExpression* entry, int translationId);
+    void setTranslation(KEduVocExpression *entry, int translationId);
 
     /** Expand all the lessons and its corresponding sub-lessons **/
     void expandAllLesson();
@@ -70,18 +75,21 @@ public slots:
     void collapseAllLesson();
 
 protected slots:
-    void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected) Q_DECL_OVERRIDE;
-    void currentChanged(const QModelIndex & current, const QModelIndex & previous) Q_DECL_OVERRIDE;
+    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
+    void currentChanged(const QModelIndex &current, const QModelIndex &previous) override;
 
 private:
-    void setModel(ContainerModel *model) Q_DECL_OVERRIDE {
+    void setModel(ContainerModel *model) override
+    {
         Q_UNUSED(model)
     }
-    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE {
+    void setModel(QAbstractItemModel *model) override
+    {
         Q_UNUSED(model)
     }
 
-    LessonModel *m_model;
+    LessonModel *m_model{nullptr};
+    EditorWindow *m_editorWindow{nullptr};
 };
 }
 
