@@ -17,17 +17,16 @@ class ExportDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ExportDialog(ParleyDocument *doc, QWidget *parent = 0);
+    explicit ExportDialog(ParleyDocument *doc, QWidget *parent = nullptr);
 
 private slots:
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
 private:
-    QUrl getFileName(const QString& filter);
+    QUrl getFileName(const QString &filter);
 
-    Ui::ExportOptions* ui;
-    ParleyDocument *m_doc;
-    QWidget *m_parent;
+    Ui::ExportOptions *ui{nullptr};
+    ParleyDocument *m_doc{nullptr};
 };
 
 #endif
