@@ -3,7 +3,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef LANGUAGEPROPERTIESPAGE_H
 #define LANGUAGEPROPERTIESPAGE_H
 
@@ -15,7 +14,7 @@ class LanguagePropertiesPage : public QWidget, public Ui::LanguagePropertiesPage
 {
     Q_OBJECT
 public:
-    LanguagePropertiesPage(KEduVocDocument *doc, int identifierIndex, QWidget *parent = 0);
+    LanguagePropertiesPage(KEduVocDocument *doc, int identifierIndex, QWidget *parent = nullptr);
     void setLanguageIdentifierIndex(int newIndex);
 
 public slots:
@@ -23,10 +22,10 @@ public slots:
     void downloadGrammar();
 
 signals:
-    void nameChanged(const QString&);
+    void nameChanged(const QString &);
 
 private slots:
-    void localeChanged(const QString&);
+    void localeChanged(const QString &);
 
     // pronouns/conjugations
     void updateCheckBoxes();
@@ -46,8 +45,8 @@ private:
     int m_currentTense;
     QList<int> tenseIndex;
 
-    KEduVocDocument* m_doc;
-    int m_identifierIndex;
+    KEduVocDocument *m_doc{nullptr};
+    int m_identifierIndex{0};
 };
 
 #endif
